summaryrefslogtreecommitdiffstats
path: root/core
diff options
context:
space:
mode:
Diffstat (limited to 'core')
-rw-r--r--core/js/js.js111
-rw-r--r--core/js/oc-dialogs.js12
-rw-r--r--core/js/tests/specs/coreSpec.js32
-rw-r--r--core/l10n/ast.php74
-rw-r--r--core/l10n/ca.php1
-rw-r--r--core/l10n/cs_CZ.php1
-rw-r--r--core/l10n/da.php1
-rw-r--r--core/l10n/de.php1
-rw-r--r--core/l10n/de_CH.php1
-rw-r--r--core/l10n/de_DE.php1
-rw-r--r--core/l10n/el.php1
-rw-r--r--core/l10n/en_GB.php2
-rw-r--r--core/l10n/eo.php1
-rw-r--r--core/l10n/es.php2
-rw-r--r--core/l10n/es_AR.php1
-rw-r--r--core/l10n/et_EE.php1
-rw-r--r--core/l10n/eu.php1
-rw-r--r--core/l10n/fa.php1
-rw-r--r--core/l10n/fi_FI.php4
-rw-r--r--core/l10n/fr.php1
-rw-r--r--core/l10n/gl.php2
-rw-r--r--core/l10n/he.php1
-rw-r--r--core/l10n/hu_HU.php1
-rw-r--r--core/l10n/it.php1
-rw-r--r--core/l10n/ja.php1
-rw-r--r--core/l10n/jv.php9
-rw-r--r--core/l10n/ka_GE.php1
-rw-r--r--core/l10n/lv.php1
-rw-r--r--core/l10n/nl.php2
-rw-r--r--core/l10n/pl.php2
-rw-r--r--core/l10n/pt_BR.php2
-rw-r--r--core/l10n/pt_PT.php1
-rw-r--r--core/l10n/ru.php1
-rw-r--r--core/l10n/sk_SK.php14
-rw-r--r--core/l10n/sl.php1
-rw-r--r--core/l10n/sv.php2
-rw-r--r--core/l10n/th_TH.php1
-rw-r--r--core/l10n/tr.php2
-rw-r--r--core/l10n/uk.php1
-rw-r--r--core/l10n/vi.php1
-rw-r--r--core/l10n/zh_CN.php1
-rw-r--r--core/l10n/zh_TW.php1
42 files changed, 259 insertions, 40 deletions
diff --git a/core/js/oc-dialogs.js b/core/js/oc-dialogs.js
index 4da56f27d27..2233b983ad4 100644
--- a/core/js/oc-dialogs.js
+++ b/core/js/oc-dialogs.js
@@ -19,6 +19,8 @@
*
*/
+/* global OC, t */
+
/**
* this class to ease the usage of jquery dialogs
*/
@@ -138,6 +140,9 @@ var OCdialogs = {
self.$filePicker = null;
}
});
+ if (!OC.Util.hasSVGSupport()) {
+ OC.Util.replaceSVG(self.$filePicker.parent());
+ }
})
.fail(function(status, error) {
// If the method is called while navigating away
@@ -560,7 +565,6 @@ var OCdialogs = {
filename: entry.name,
date: OC.mtime2date(Math.floor(entry.mtime / 1000))
});
- $li.find('img').attr('src', entry.icon);
if (entry.isPreviewAvailable) {
var urlSpec = {
file: dir + '/' + entry.name
@@ -568,10 +572,16 @@ var OCdialogs = {
var previewUrl = OC.generateUrl('/core/preview.png?') + $.param(urlSpec);
$li.find('img').attr('src', previewUrl);
}
+ else {
+ $li.find('img').attr('src', OC.Util.replaceSVGIcon(entry.icon));
+ }
self.$filelist.append($li);
});
self.$filelist.removeClass('loading');
+ if (!OC.Util.hasSVGSupport()) {
+ OC.Util.replaceSVG(self.$filePicker.find('.dirtree'));
+ }
});
},
/**
diff --git a/core/js/tests/specs/coreSpec.js b/core/js/tests/specs/coreSpec.js
index 94a397b7892..ccd9f7a1288 100644
--- a/core/js/tests/specs/coreSpec.js
+++ b/core/js/tests/specs/coreSpec.js
@@ -147,19 +147,19 @@ describe('Core base tests', function() {
});
describe('Images', function() {
it('Generates image path with given extension', function() {
- var svgSupportStub = sinon.stub(window, 'SVGSupport', function() { return true; });
+ var svgSupportStub = sinon.stub(OC.Util, 'hasSVGSupport', function() { return true; });
expect(OC.imagePath('core', 'somefile.jpg')).toEqual(OC.webroot + '/core/img/somefile.jpg');
expect(OC.imagePath(TESTAPP, 'somefile.jpg')).toEqual(TESTAPP_ROOT + '/img/somefile.jpg');
svgSupportStub.restore();
});
it('Generates image path with svg extension when svg support exists', function() {
- var svgSupportStub = sinon.stub(window, 'SVGSupport', function() { return true; });
+ var svgSupportStub = sinon.stub(OC.Util, 'hasSVGSupport', function() { return true; });
expect(OC.imagePath('core', 'somefile')).toEqual(OC.webroot + '/core/img/somefile.svg');
expect(OC.imagePath(TESTAPP, 'somefile')).toEqual(TESTAPP_ROOT + '/img/somefile.svg');
svgSupportStub.restore();
});
it('Generates image path with png ext when svg support is not available', function() {
- var svgSupportStub = sinon.stub(window, 'SVGSupport', function() { return false; });
+ var svgSupportStub = sinon.stub(OC.Util, 'hasSVGSupport', function() { return false; });
expect(OC.imagePath('core', 'somefile')).toEqual(OC.webroot + '/core/img/somefile.png');
expect(OC.imagePath(TESTAPP, 'somefile')).toEqual(TESTAPP_ROOT + '/img/somefile.png');
svgSupportStub.restore();
@@ -448,5 +448,31 @@ describe('Core base tests', function() {
expect($navigation.is(':visible')).toEqual(true);
});
});
+ describe('SVG extension replacement', function() {
+ var svgSupportStub;
+
+ beforeEach(function() {
+ svgSupportStub = sinon.stub(OC.Util, 'hasSVGSupport');
+ });
+ afterEach(function() {
+ svgSupportStub.restore();
+ });
+ it('does not replace svg extension with png when SVG is supported', function() {
+ svgSupportStub.returns(true);
+ expect(
+ OC.Util.replaceSVGIcon('/path/to/myicon.svg?someargs=1')
+ ).toEqual(
+ '/path/to/myicon.svg?someargs=1'
+ );
+ });
+ it('replaces svg extension with png when SVG not supported', function() {
+ svgSupportStub.returns(false);
+ expect(
+ OC.Util.replaceSVGIcon('/path/to/myicon.svg?someargs=1')
+ ).toEqual(
+ '/path/to/myicon.png?someargs=1'
+ );
+ });
+ });
});
diff --git a/core/l10n/ast.php b/core/l10n/ast.php
new file mode 100644
index 00000000000..9ae1685347c
--- /dev/null
+++ b/core/l10n/ast.php
@@ -0,0 +1,74 @@
+<?php
+$TRANSLATIONS = array(
+"Updated database" => "Base de datos anovada",
+"Sunday" => "Domingu",
+"Monday" => "Llunes",
+"Tuesday" => "Martes",
+"Wednesday" => "Miércoles",
+"Thursday" => "Xueves",
+"Friday" => "Vienres",
+"Saturday" => "Sábadu",
+"January" => "Xineru",
+"February" => "Febreru",
+"March" => "Marzu",
+"April" => "Abril",
+"May" => "Mayu",
+"June" => "Xunu",
+"July" => "Xunetu",
+"August" => "Agostu",
+"September" => "Setiembre",
+"October" => "Ochobre",
+"November" => "Payares",
+"December" => "Avientu",
+"Settings" => "Axustes",
+"seconds ago" => "fai segundos",
+"_%n minute ago_::_%n minutes ago_" => array("fai %n minutu","fai %n minutos"),
+"_%n hour ago_::_%n hours ago_" => array("fai %n hora","fai %n hores"),
+"today" => "güei",
+"yesterday" => "ayeri",
+"_%n day ago_::_%n days ago_" => array("fai %n día","fai %n díes"),
+"last month" => "mes caberu",
+"_%n month ago_::_%n months ago_" => array("fai %n mes","fai %n meses"),
+"months ago" => "fai meses",
+"last year" => "añu caberu",
+"years ago" => "fai años",
+"Choose" => "Esbillar",
+"Yes" => "Sí",
+"No" => "Non",
+"_{count} file conflict_::_{count} file conflicts_" => array("",""),
+"Which files do you want to keep?" => "¿Qué ficheros quies caltener?",
+"Cancel" => "Encaboxar",
+"Continue" => "Continuar",
+"Shared" => "Compartíu",
+"Share" => "Compartir",
+"Share link" => "Compartir enllaz",
+"Password" => "Contraseña",
+"Send" => "Unviar",
+"group" => "grupu",
+"Unshare" => "Dexar de compartir",
+"notify by email" => "notificar per corréu",
+"can edit" => "pue editar",
+"access control" => "control d'accesu",
+"create" => "crear",
+"update" => "xubir",
+"delete" => "desaniciar",
+"share" => "compartir",
+"Password protected" => "Contraseña protexida",
+"Email sent" => "Corréu unviáu",
+"Delete" => "Desaniciar",
+"Add" => "Amestar",
+"Edit tags" => "Editar etiquetes",
+"Username" => "Nome d'usuariu",
+"Reset" => "Reaniciar",
+"For the best results, please consider using a GNU/Linux server instead." => "Pa los meyores resultaos, por favor considera l'usu d'un sirvidor GNU/Linux nel so llugar.",
+"Personal" => "Personal",
+"Cheers!" => "¡Salú!",
+"will be used" => "usaráse",
+"Finishing …" => "Finando ...",
+"Log out" => "Zarrar sesión",
+"Lost your password?" => "¿Escaeciesti la to contraseña?",
+"Log in" => "Aniciar sesión",
+"Alternative Logins" => "Anicios de sesión alternativos",
+"Thank you for your patience." => "Gracies pola to paciencia."
+);
+$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
diff --git a/core/l10n/ca.php b/core/l10n/ca.php
index 0a658d515d9..214b2eac0e9 100644
--- a/core/l10n/ca.php
+++ b/core/l10n/ca.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Error en carregar la plantilla de missatge: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflicte de fitxer","{count} conflictes de fitxer"),
"One file conflict" => "Un fitxer en conflicte",
+"New Files" => "Fitxers nous",
"Which files do you want to keep?" => "Quin fitxer voleu conservar?",
"If you select both versions, the copied file will have a number added to its name." => "Si seleccioneu les dues versions, el fitxer copiat tindrà un número afegit al seu nom.",
"Cancel" => "Cancel·la",
diff --git a/core/l10n/cs_CZ.php b/core/l10n/cs_CZ.php
index ffe34f78280..c21d904b233 100644
--- a/core/l10n/cs_CZ.php
+++ b/core/l10n/cs_CZ.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Chyba při nahrávání šablony zprávy: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} souborový konflikt","{count} souborové konflikty","{count} souborových konfliktů"),
"One file conflict" => "Jeden konflikt souboru",
+"New Files" => "Nové soubory",
"Which files do you want to keep?" => "Které soubory chcete ponechat?",
"If you select both versions, the copied file will have a number added to its name." => "Pokud zvolíte obě verze, zkopírovaný soubor bude mít název doplněný o číslo.",
"Cancel" => "Zrušit",
diff --git a/core/l10n/da.php b/core/l10n/da.php
index d3384dac432..c7bda6fd365 100644
--- a/core/l10n/da.php
+++ b/core/l10n/da.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Fejl ved indlæsning af besked skabelon: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} filkonflikt","{count} filkonflikter"),
"One file conflict" => "En filkonflikt",
+"New Files" => "Nye filer",
"Which files do you want to keep?" => "Hvilke filer ønsker du at beholde?",
"If you select both versions, the copied file will have a number added to its name." => "Hvis du vælger begge versioner, vil den kopierede fil få tilføjet et nummer til sit navn.",
"Cancel" => "Annuller",
diff --git a/core/l10n/de.php b/core/l10n/de.php
index 79edfb725d7..4d8c583e164 100644
--- a/core/l10n/de.php
+++ b/core/l10n/de.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Fehler beim Laden der Nachrichtenvorlage: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} Dateikonflikt","{count} Dateikonflikte"),
"One file conflict" => "Ein Dateikonflikt",
+"New Files" => "Neue Dateien",
"Which files do you want to keep?" => "Welche Dateien möchtest Du behalten?",
"If you select both versions, the copied file will have a number added to its name." => "Wenn Du beide Versionen auswählst, erhält die kopierte Datei eine Zahl am Ende des Dateinamens.",
"Cancel" => "Abbrechen",
diff --git a/core/l10n/de_CH.php b/core/l10n/de_CH.php
index 42b8eb3bcea..eb2cfd233d3 100644
--- a/core/l10n/de_CH.php
+++ b/core/l10n/de_CH.php
@@ -40,6 +40,7 @@ $TRANSLATIONS = array(
"No" => "Nein",
"Ok" => "OK",
"_{count} file conflict_::_{count} file conflicts_" => array("",""),
+"New Files" => "Neue Dateien",
"Cancel" => "Abbrechen",
"Shared" => "Geteilt",
"Share" => "Teilen",
diff --git a/core/l10n/de_DE.php b/core/l10n/de_DE.php
index a0877e792e2..900d3c03172 100644
--- a/core/l10n/de_DE.php
+++ b/core/l10n/de_DE.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Fehler beim Laden der Nachrichtenvorlage: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} Dateikonflikt","{count} Dateikonflikte"),
"One file conflict" => "Ein Dateikonflikt",
+"New Files" => "Neue Dateien",
"Which files do you want to keep?" => "Welche Dateien möchten Sie behalten?",
"If you select both versions, the copied file will have a number added to its name." => "Wenn Sie beide Versionen auswählen, erhält die kopierte Datei eine Zahl am Ende des Dateinamens.",
"Cancel" => "Abbrechen",
diff --git a/core/l10n/el.php b/core/l10n/el.php
index 0ffb746fc77..c899427ae30 100644
--- a/core/l10n/el.php
+++ b/core/l10n/el.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Σφάλμα φόρτωσης προτύπου μηνυμάτων: {σφάλμα}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} αρχείο διαφέρει","{count} αρχεία διαφέρουν"),
"One file conflict" => "Ένα αρχείο διαφέρει",
+"New Files" => "Νέα Αρχεία",
"Which files do you want to keep?" => "Ποια αρχεία θέλετε να κρατήσετε;",
"If you select both versions, the copied file will have a number added to its name." => "Εάν επιλέξετε και τις δυο εκδοχές, ένας αριθμός θα προστεθεί στο αντιγραφόμενο αρχείο.",
"Cancel" => "Άκυρο",
diff --git a/core/l10n/en_GB.php b/core/l10n/en_GB.php
index bc36f5a4446..215bae92d1c 100644
--- a/core/l10n/en_GB.php
+++ b/core/l10n/en_GB.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Error loading message template: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} file conflict","{count} file conflicts"),
"One file conflict" => "One file conflict",
+"New Files" => "New Files",
+"Already existing files" => "Already existing files",
"Which files do you want to keep?" => "Which files do you wish to keep?",
"If you select both versions, the copied file will have a number added to its name." => "If you select both versions, the copied file will have a number added to its name.",
"Cancel" => "Cancel",
diff --git a/core/l10n/eo.php b/core/l10n/eo.php
index f264b7ed7a7..05d28efb66b 100644
--- a/core/l10n/eo.php
+++ b/core/l10n/eo.php
@@ -41,6 +41,7 @@ $TRANSLATIONS = array(
"Ok" => "Akcepti",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} dosierkonflikto","{count} dosierkonfliktoj"),
"One file conflict" => "Unu dosierkonflikto",
+"New Files" => "Novaj dosieroj",
"Which files do you want to keep?" => "Kiujn dosierojn vi volas konservi?",
"If you select both versions, the copied file will have a number added to its name." => "Se vi elektos ambaŭ eldonojn, la kopiota dosiero havos numeron aldonitan al sia nomo.",
"Cancel" => "Nuligi",
diff --git a/core/l10n/es.php b/core/l10n/es.php
index 52f1a15089a..cb2d09d60fe 100644
--- a/core/l10n/es.php
+++ b/core/l10n/es.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Error cargando plantilla del mensaje: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflicto de archivo","{count} conflictos de archivo"),
"One file conflict" => "On conflicto de archivo",
+"New Files" => "Nuevos Archivos",
+"Already existing files" => "Archivos ya existentes",
"Which files do you want to keep?" => "¿Que archivos deseas mantener?",
"If you select both versions, the copied file will have a number added to its name." => "Si seleccionas ambas versiones, el archivo copiado tendrá añadido un número en su nombre.",
"Cancel" => "Cancelar",
diff --git a/core/l10n/es_AR.php b/core/l10n/es_AR.php
index b5b37d4825b..c9d270edefa 100644
--- a/core/l10n/es_AR.php
+++ b/core/l10n/es_AR.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Error cargando la plantilla del mensaje: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("un archivo en conflicto","{count} archivos en conflicto"),
"One file conflict" => "Un archivo en conflicto",
+"New Files" => "Nuevos archivos",
"Which files do you want to keep?" => "¿Qué archivos deseas retener?",
"If you select both versions, the copied file will have a number added to its name." => "Si tu seleccionas ambas versiones, el archivo copiado tendrá un número agregado a su nombre.",
"Cancel" => "Cancelar",
diff --git a/core/l10n/et_EE.php b/core/l10n/et_EE.php
index e9c23d96b81..422caac9c15 100644
--- a/core/l10n/et_EE.php
+++ b/core/l10n/et_EE.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Viga sõnumi malli laadimisel: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} failikonflikt","{count} failikonflikti"),
"One file conflict" => "Üks failikonflikt",
+"New Files" => "Uued failid",
"Which files do you want to keep?" => "Milliseid faile sa soovid alles hoida?",
"If you select both versions, the copied file will have a number added to its name." => "Kui valid mõlemad versioonid, siis lisatakse kopeeritud faili nimele number.",
"Cancel" => "Loobu",
diff --git a/core/l10n/eu.php b/core/l10n/eu.php
index 33c98fb9b90..8fd554485db 100644
--- a/core/l10n/eu.php
+++ b/core/l10n/eu.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Errorea mezu txantiloia kargatzean: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("fitxategi {count}ek konfliktua sortu du","{count} fitxategik konfliktua sortu dute"),
"One file conflict" => "Fitxategi batek konfliktua sortu du",
+"New Files" => "Fitxategi Berriak",
"Which files do you want to keep?" => "Ze fitxategi mantendu nahi duzu?",
"If you select both versions, the copied file will have a number added to its name." => "Bi bertsioak hautatzen badituzu, kopiatutako fitxategiaren izenean zenbaki bat atxikituko zaio.",
"Cancel" => "Ezeztatu",
diff --git a/core/l10n/fa.php b/core/l10n/fa.php
index 3e7e246e827..a349d3b7704 100644
--- a/core/l10n/fa.php
+++ b/core/l10n/fa.php
@@ -37,6 +37,7 @@ $TRANSLATIONS = array(
"No" => "نه",
"Ok" => "قبول",
"_{count} file conflict_::_{count} file conflicts_" => array(""),
+"New Files" => "فایل های جدید",
"Cancel" => "منصرف شدن",
"Shared" => "اشتراک گذاشته شده",
"Share" => "اشتراک‌گذاری",
diff --git a/core/l10n/fi_FI.php b/core/l10n/fi_FI.php
index 0af7503ee9d..7797d17c872 100644
--- a/core/l10n/fi_FI.php
+++ b/core/l10n/fi_FI.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Virhe ladatessa viestipohjaa: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} tiedoston ristiriita","{count} tiedoston ristiriita"),
"One file conflict" => "Yhden tiedoston ristiriita",
+"New Files" => "Uudet tiedostot",
+"Already existing files" => "Jo olemassa olevat tiedostot",
"Which files do you want to keep?" => "Mitkä tiedostot haluat säilyttää?",
"If you select both versions, the copied file will have a number added to its name." => "Jos valitset kummatkin versiot, kopioidun tiedoston nimeen lisätään numero.",
"Cancel" => "Peru",
@@ -122,6 +124,8 @@ $TRANSLATIONS = array(
"To login page" => "Kirjautumissivulle",
"New password" => "Uusi salasana",
"Reset password" => "Palauta salasana",
+"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X ei ole tuettu, joten %s ei toimi kunnolla tällä alustalla. Käytä omalla vastuulla!",
+"For the best results, please consider using a GNU/Linux server instead." => "Käytä parhaan lopputuloksen saamiseksi GNU/Linux-palvelinta.",
"Personal" => "Henkilökohtainen",
"Users" => "Käyttäjät",
"Apps" => "Sovellukset",
diff --git a/core/l10n/fr.php b/core/l10n/fr.php
index f5a1ecd42fb..2475eddee8a 100644
--- a/core/l10n/fr.php
+++ b/core/l10n/fr.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Erreur de chargement du modèle de message : {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} fichier en conflit","{count} fichiers en conflit"),
"One file conflict" => "Un conflit de fichier",
+"New Files" => "Nouveaux fichiers",
"Which files do you want to keep?" => "Quels fichiers désirez-vous garder ?",
"If you select both versions, the copied file will have a number added to its name." => "Si vous sélectionnez les deux versions, un nombre sera ajouté au nom du fichier copié.",
"Cancel" => "Annuler",
diff --git a/core/l10n/gl.php b/core/l10n/gl.php
index c1c678e7e3f..eb9f1af5657 100644
--- a/core/l10n/gl.php
+++ b/core/l10n/gl.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Produciuse un erro ao cargar o modelo da mensaxe: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflito de ficheiro","{count} conflitos de ficheiros"),
"One file conflict" => "Un conflito de ficheiro",
+"New Files" => "Ficheiros novos",
+"Already existing files" => "Ficheiros xa existentes",
"Which files do you want to keep?" => "Que ficheiros quere conservar?",
"If you select both versions, the copied file will have a number added to its name." => "Se selecciona ambas versións, o ficheiro copiado terá un número engadido ao nome.",
"Cancel" => "Cancelar",
diff --git a/core/l10n/he.php b/core/l10n/he.php
index 4579626f12d..8fb7373a143 100644
--- a/core/l10n/he.php
+++ b/core/l10n/he.php
@@ -37,6 +37,7 @@ $TRANSLATIONS = array(
"No" => "לא",
"Ok" => "בסדר",
"_{count} file conflict_::_{count} file conflicts_" => array("",""),
+"New Files" => "קבצים חדשים",
"Cancel" => "ביטול",
"Shared" => "שותף",
"Share" => "שתף",
diff --git a/core/l10n/hu_HU.php b/core/l10n/hu_HU.php
index e81991ec7ad..096b28e2d9b 100644
--- a/core/l10n/hu_HU.php
+++ b/core/l10n/hu_HU.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Nem sikerült betölteni az üzenet sablont: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} fájl ütközik","{count} fájl ütközik"),
"One file conflict" => "Egy file ütközik",
+"New Files" => "Új fájlok",
"Which files do you want to keep?" => "Melyik file-okat akarod megtartani?",
"If you select both versions, the copied file will have a number added to its name." => "Ha kiválasztod mindazokaz a verziókat, a másolt fileok neve sorszámozva lesz.",
"Cancel" => "Mégsem",
diff --git a/core/l10n/it.php b/core/l10n/it.php
index 2f0017263fa..43e9752f5e0 100644
--- a/core/l10n/it.php
+++ b/core/l10n/it.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Errore durante il caricamento del modello di messaggio: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} file in conflitto","{count} file in conflitto"),
"One file conflict" => "Un file in conflitto",
+"New Files" => "File nuovi",
"Which files do you want to keep?" => "Quali file vuoi mantenere?",
"If you select both versions, the copied file will have a number added to its name." => "Se selezioni entrambe le versioni, sarà aggiunto un numero al nome del file copiato.",
"Cancel" => "Annulla",
diff --git a/core/l10n/ja.php b/core/l10n/ja.php
index 5f8d6a05ae9..3a99f0e598b 100644
--- a/core/l10n/ja.php
+++ b/core/l10n/ja.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "メッセージテンプレートの読み込みエラー: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} ファイルが競合"),
"One file conflict" => "1ファイルが競合",
+"New Files" => "新しいファイル",
"Which files do you want to keep?" => "どちらのファイルを保持したいですか?",
"If you select both versions, the copied file will have a number added to its name." => "両方のバージョンを選択した場合は、ファイル名の後ろに数字を追加したファイルのコピーを作成します。",
"Cancel" => "キャンセル",
diff --git a/core/l10n/jv.php b/core/l10n/jv.php
new file mode 100644
index 00000000000..ffcdde48d47
--- /dev/null
+++ b/core/l10n/jv.php
@@ -0,0 +1,9 @@
+<?php
+$TRANSLATIONS = array(
+"_%n minute ago_::_%n minutes ago_" => array("",""),
+"_%n hour ago_::_%n hours ago_" => array("",""),
+"_%n day ago_::_%n days ago_" => array("",""),
+"_%n month ago_::_%n months ago_" => array("",""),
+"_{count} file conflict_::_{count} file conflicts_" => array("","")
+);
+$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
diff --git a/core/l10n/ka_GE.php b/core/l10n/ka_GE.php
index 0070fd7994e..a76a8866541 100644
--- a/core/l10n/ka_GE.php
+++ b/core/l10n/ka_GE.php
@@ -37,6 +37,7 @@ $TRANSLATIONS = array(
"No" => "არა",
"Ok" => "დიახ",
"_{count} file conflict_::_{count} file conflicts_" => array(""),
+"New Files" => "ახალი ფაილები",
"Cancel" => "უარყოფა",
"Shared" => "გაზიარებული",
"Share" => "გაზიარება",
diff --git a/core/l10n/lv.php b/core/l10n/lv.php
index 505bf46b4c9..683ff2c129a 100644
--- a/core/l10n/lv.php
+++ b/core/l10n/lv.php
@@ -37,6 +37,7 @@ $TRANSLATIONS = array(
"No" => "Nē",
"Ok" => "Labi",
"_{count} file conflict_::_{count} file conflicts_" => array("","",""),
+"New Files" => "Jaunās datnes",
"Cancel" => "Atcelt",
"Shared" => "Kopīgs",
"Share" => "Dalīties",
diff --git a/core/l10n/nl.php b/core/l10n/nl.php
index 05cef6afd5a..b09509e6290 100644
--- a/core/l10n/nl.php
+++ b/core/l10n/nl.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Fout bij laden berichtensjabloon: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} bestandsconflict","{count} bestandsconflicten"),
"One file conflict" => "Een bestandsconflict",
+"New Files" => "Nieuwe bestanden",
+"Already existing files" => "Al aanwezige bestanden",
"Which files do you want to keep?" => "Welke bestanden wilt u bewaren?",
"If you select both versions, the copied file will have a number added to its name." => "Als u beide versies selecteerde, zal het gekopieerde bestand een nummer aan de naam toegevoegd krijgen.",
"Cancel" => "Annuleer",
diff --git a/core/l10n/pl.php b/core/l10n/pl.php
index 17fde36c7cd..fe0cf145832 100644
--- a/core/l10n/pl.php
+++ b/core/l10n/pl.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Błąd podczas ładowania szablonu wiadomości: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} konfliktów plików","{count} konfliktów plików","{count} konfliktów plików"),
"One file conflict" => "Konflikt pliku",
+"New Files" => "Nowe pliki",
+"Already existing files" => "Już istniejące pliki",
"Which files do you want to keep?" => "Które pliki chcesz zachować?",
"If you select both versions, the copied file will have a number added to its name." => "Jeśli wybierzesz obie wersje, skopiowany plik będzie miał dodany numerek w nazwie",
"Cancel" => "Anuluj",
diff --git a/core/l10n/pt_BR.php b/core/l10n/pt_BR.php
index b31925cdf79..3545426b670 100644
--- a/core/l10n/pt_BR.php
+++ b/core/l10n/pt_BR.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Erro no carregamento de modelo de mensagem: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflito de arquivo","{count} conflitos de arquivos"),
"One file conflict" => "Conflito em um arquivo",
+"New Files" => "Novos Arquivos",
+"Already existing files" => "Arquivos já existentes",
"Which files do you want to keep?" => "Qual arquivo você quer manter?",
"If you select both versions, the copied file will have a number added to its name." => "Se você selecionar ambas as versões, o arquivo copiado terá um número adicionado ao seu nome.",
"Cancel" => "Cancelar",
diff --git a/core/l10n/pt_PT.php b/core/l10n/pt_PT.php
index a4d6785cd5e..bb1b6011a6b 100644
--- a/core/l10n/pt_PT.php
+++ b/core/l10n/pt_PT.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Erro ao carregar o template: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} conflicto de ficheiro","{count} conflitos de ficheiro"),
"One file conflict" => "Um conflito no ficheiro",
+"New Files" => "Ficheiros Novos",
"Which files do you want to keep?" => "Quais os ficheiros que pretende manter?",
"If you select both versions, the copied file will have a number added to its name." => "Se escolher ambas as versões, o ficheiro copiado irá ter um número adicionado ao seu nome.",
"Cancel" => "Cancelar",
diff --git a/core/l10n/ru.php b/core/l10n/ru.php
index e2fdc36be0b..aa784088f7a 100644
--- a/core/l10n/ru.php
+++ b/core/l10n/ru.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Ошибка загрузки шаблона сообщений: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} конфликт в файлах","{count} конфликта в файлах","{count} конфликтов в файлах"),
"One file conflict" => "Один конфликт в файлах",
+"New Files" => "Новые файлы",
"Which files do you want to keep?" => "Какие файлы вы хотите сохранить?",
"If you select both versions, the copied file will have a number added to its name." => "При выборе обоих версий, к названию копируемого файла будет добавлена цифра",
"Cancel" => "Отменить",
diff --git a/core/l10n/sk_SK.php b/core/l10n/sk_SK.php
index bb3c9863ce2..1b717bc412e 100644
--- a/core/l10n/sk_SK.php
+++ b/core/l10n/sk_SK.php
@@ -1,5 +1,6 @@
<?php
$TRANSLATIONS = array(
+"Expiration date is in the past." => " \t\nDátum expirácie spadá do minulosti.",
"Couldn't send mail to following users: %s " => "Nebolo možné odoslať email týmto používateľom: %s ",
"Turned on maintenance mode" => "Mód údržby je zapnutý",
"Turned off maintenance mode" => "Mód údržby e vypnutý",
@@ -49,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Chyba pri nahrávaní šablóny správy: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} konflikt súboru","{count} konflikty súboru","{count} konfliktov súboru"),
"One file conflict" => "Jeden konflikt súboru",
+"New Files" => "Nové súbory",
"Which files do you want to keep?" => "Ktoré súbory chcete ponechať?",
"If you select both versions, the copied file will have a number added to its name." => "Ak zvolíte obe verzie, názov nakopírovaného súboru bude doplnený o číslo.",
"Cancel" => "Zrušiť",
@@ -56,6 +58,11 @@ $TRANSLATIONS = array(
"(all selected)" => "(všetko vybrané)",
"({count} selected)" => "({count} vybraných)",
"Error loading file exists template" => "Chyba pri nahrávaní šablóny existencie súboru",
+"Very weak password" => "Veľmi slabé heslo",
+"Weak password" => "Slabé heslo",
+"So-so password" => "Priemerné heslo",
+"Good password" => "Dobré heslo",
+"Strong password" => "Silné heslo",
"Shared" => "Zdieľané",
"Share" => "Zdieľať",
"Error" => "Chyba",
@@ -103,6 +110,7 @@ $TRANSLATIONS = array(
"The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." => "Aktualizácia nebola úspešná. Problém nahláste <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud comunite</a>.",
"The update was successful. Redirecting you to ownCloud now." => "Aktualizácia bola úspešná. Presmerovávam vás na prihlasovaciu stránku.",
"%s password reset" => "reset hesla %s",
+"A problem has occurred whilst sending the email, please contact your administrator." => "Vyskytol sa problém pri odosielaní emailu, prosím obráťte sa na správcu.",
"Use the following link to reset your password: {link}" => "Použite nasledujúci odkaz pre obnovenie vášho hesla: {link}",
"The link to reset your password has been sent to your email.<br>If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator ." => "Odkaz na obnovenie hesla bol odoslaný na vašu emailovú adresu.<br>Ak ho v krátkej dobe neobdržíte, skontrolujte si váš kôš a priečinok spam.<br>Ak ho ani tam nenájdete, kontaktujte svojho administrátora.",
"Request failed!<br>Did you make sure your email/username was right?" => "Požiadavka zlyhala.<br>Uistili ste sa, že vaše používateľské meno a email sú správne?",
@@ -115,6 +123,8 @@ $TRANSLATIONS = array(
"To login page" => "Na prihlasovaciu stránku",
"New password" => "Nové heslo",
"Reset password" => "Obnovenie hesla",
+"Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " => "Mac OS X nie je podporovaný a %s nebude správne fungovať na tejto platforme. Použite ho na vlastné riziko!",
+"For the best results, please consider using a GNU/Linux server instead." => "Pre dosiahnutie najlepších výsledkov, prosím zvážte použitie GNU/Linux servera.",
"Personal" => "Osobné",
"Users" => "Používatelia",
"Apps" => "Aplikácie",
@@ -129,7 +139,7 @@ $TRANSLATIONS = array(
"Error unfavoriting" => "Chyba pri odobratí z obľúbených",
"Access forbidden" => "Prístup odmietnutý",
"Cloud not found" => "Nenájdené",
-"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Ahoj,\n\nchcem ti dať navedomie, že %s s tebou zdieľa %s.\nTu je odkaz: %s\n\n",
+"Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" => "Dobrý deň,\n\nPoužívateľ %s zdieľa s vami súbor, alebo priečinok s názvom %s.\nPre zobrazenie kliknite na túto linku: %s\n",
"The share will expire on %s." => "Zdieľanie expiruje %s.",
"Cheers!" => "Pekný deň!",
"Security Warning" => "Bezpečnostné varovanie",
@@ -140,6 +150,7 @@ $TRANSLATIONS = array(
"Your data directory and files are probably accessible from the internet because the .htaccess file does not work." => "Váš priečinok s dátami a súbormi je dostupný z internetu, lebo súbor .htaccess nefunguje.",
"For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." => "Pre informácie, ako správne nastaviť váš server, sa pozrite do <a href=\"%s\" target=\"_blank\">dokumentácie</a>.",
"Create an <strong>admin account</strong>" => "Vytvoriť <strong>administrátorský účet</strong>",
+"Storage & database" => "Úložislo & databáza",
"Data folder" => "Priečinok dát",
"Configure the database" => "Nastaviť databázu",
"will be used" => "bude použité",
@@ -162,6 +173,7 @@ $TRANSLATIONS = array(
"remember" => "zapamätať",
"Log in" => "Prihlásiť sa",
"Alternative Logins" => "Alternatívne prihlásenie",
+"Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" => "Dobrý deň,<br><br>Používateľ %s zdieľa s vami súbor, alebo priečinok s názvom »%s«.<br><a href=\"%s\">Pre zobrazenie kliknite na túto linku!</a><br><br>",
"This ownCloud instance is currently in single user mode." => "Táto inštancia ownCloudu je teraz v jednopoužívateľskom móde.",
"This means only administrators can use the instance." => "Len správca systému môže používať túto inštanciu.",
"Contact your system administrator if this message persists or appeared unexpectedly." => "Kontaktujte prosím správcu systému, ak sa táto správa objavuje opakovane alebo neočakávane.",
diff --git a/core/l10n/sl.php b/core/l10n/sl.php
index 49eb4f9aa69..7476d9f9c7c 100644
--- a/core/l10n/sl.php
+++ b/core/l10n/sl.php
@@ -50,6 +50,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Napaka nalaganja predloge sporočil: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} spor datotek","{count} spora datotek","{count} spori datotek","{count} sporov datotek"),
"One file conflict" => "En spor datotek",
+"New Files" => "Nove datoteke",
"Which files do you want to keep?" => "Katare datoteke želite ohraniti?",
"If you select both versions, the copied file will have a number added to its name." => "Če izberete obe različici, bo kopirani datoteki k imenu dodana številka.",
"Cancel" => "Prekliči",
diff --git a/core/l10n/sv.php b/core/l10n/sv.php
index 7e72039df80..d46c204d7c3 100644
--- a/core/l10n/sv.php
+++ b/core/l10n/sv.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Fel uppstod under inläsningen av meddelandemallen: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} filkonflikt","{count} filkonflikter"),
"One file conflict" => "En filkonflikt",
+"New Files" => "Nya filer",
+"Already existing files" => "Filer som redan existerar",
"Which files do you want to keep?" => "Vilken fil vill du behålla?",
"If you select both versions, the copied file will have a number added to its name." => "Om du väljer båda versionerna kommer de kopierade filerna ha nummer tillagda i filnamnet.",
"Cancel" => "Avbryt",
diff --git a/core/l10n/th_TH.php b/core/l10n/th_TH.php
index 85a9b4ab238..9ee3c60f947 100644
--- a/core/l10n/th_TH.php
+++ b/core/l10n/th_TH.php
@@ -37,6 +37,7 @@ $TRANSLATIONS = array(
"No" => "ไม่ตกลง",
"Ok" => "ตกลง",
"_{count} file conflict_::_{count} file conflicts_" => array(""),
+"New Files" => "ไฟล์ใหม่",
"Cancel" => "ยกเลิก",
"Shared" => "แชร์แล้ว",
"Share" => "แชร์",
diff --git a/core/l10n/tr.php b/core/l10n/tr.php
index 9d211bd0570..7e75cdf4b01 100644
--- a/core/l10n/tr.php
+++ b/core/l10n/tr.php
@@ -50,6 +50,8 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "İleti şablonu yüklenirken hata: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} dosya çakışması","{count} dosya çakışması"),
"One file conflict" => "Bir dosya çakışması",
+"New Files" => "Yeni Dosyalar",
+"Already existing files" => "Zaten mevcut olan dosyalar",
"Which files do you want to keep?" => "Hangi dosyaları saklamak istiyorsunuz?",
"If you select both versions, the copied file will have a number added to its name." => "İki sürümü de seçerseniz, kopyalanan dosyanın ismine bir sayı ilave edilecektir.",
"Cancel" => "İptal",
diff --git a/core/l10n/uk.php b/core/l10n/uk.php
index ade29981b49..f6bcfdcdc8d 100644
--- a/core/l10n/uk.php
+++ b/core/l10n/uk.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Помилка при завантаженні шаблону повідомлення: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} файловий конфлікт","{count} файлових конфліктів","{count} файлових конфліктів"),
"One file conflict" => "Один файловий конфлікт",
+"New Files" => "Нових Файлів",
"Which files do you want to keep?" => "Які файли ви хочете залишити?",
"If you select both versions, the copied file will have a number added to its name." => "Якщо ви оберете обидві версії, скопійований файл буде мати номер, доданий у його ім'я.",
"Cancel" => "Відмінити",
diff --git a/core/l10n/vi.php b/core/l10n/vi.php
index be99580d942..319f68b6355 100644
--- a/core/l10n/vi.php
+++ b/core/l10n/vi.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "Lỗi khi tải mẫu thông điệp: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} tập tin xung đột"),
"One file conflict" => "Một tập tin xung đột",
+"New Files" => "File mới",
"Which files do you want to keep?" => "Bạn muốn tiếp tục với những tập tin nào?",
"If you select both versions, the copied file will have a number added to its name." => "Nếu bạn chọn cả hai phiên bản, tập tin được sao chép sẽ được đánh thêm số vào tên của nó.",
"Cancel" => "Hủy",
diff --git a/core/l10n/zh_CN.php b/core/l10n/zh_CN.php
index e5a6a254e54..68f50baf98f 100644
--- a/core/l10n/zh_CN.php
+++ b/core/l10n/zh_CN.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "加载消息模板出错: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} 个文件冲突"),
"One file conflict" => "1个文件冲突",
+"New Files" => "新文件",
"Which files do you want to keep?" => "想要保留哪一个文件呢?",
"If you select both versions, the copied file will have a number added to its name." => "如果同时选择了连个版本,复制的文件名将会添加上一个数字。",
"Cancel" => "取消",
diff --git a/core/l10n/zh_TW.php b/core/l10n/zh_TW.php
index dae143cef40..0799344697a 100644
--- a/core/l10n/zh_TW.php
+++ b/core/l10n/zh_TW.php
@@ -49,6 +49,7 @@ $TRANSLATIONS = array(
"Error loading message template: {error}" => "載入訊息樣板出錯: {error}",
"_{count} file conflict_::_{count} file conflicts_" => array("{count} 個檔案衝突"),
"One file conflict" => "一個檔案衝突",
+"New Files" => "新檔案",
"Which files do you want to keep?" => "您要保留哪一個檔案?",
"If you select both versions, the copied file will have a number added to its name." => "如果您同時選擇兩個版本,被複製的那個檔案名稱後面會加上編號",
"Cancel" => "取消",
diff --git a/core/js/js.js b/core/js/js.js
index 9a3b2ee6a5d..f10c7163092 100644
--- a/core/js/js.js
+++ b/core/js/js.js
@@ -295,7 +295,7 @@ var OC={
*/
imagePath:function(app,file){
if(file.indexOf('.')==-1){//if no extension is given, use png or svg depending on browser support
- file+=(SVGSupport())?'.svg':'.png';
+ file+=(OC.Util.hasSVGSupport())?'.svg':'.png';
}
return OC.filePath(app,'img',file);
},
@@ -497,8 +497,8 @@ var OC={
throw e;
});
}
- if(!SVGSupport()) {
- replaceSVG();
+ if(!OC.Util.hasSVGSupport()) {
+ OC.Util.replaceSVG();
}
}).show();
}, 'html');
@@ -785,7 +785,7 @@ SVGSupport.checkMimeType=function(){
}
});
if(headers["content-type"]!=='image/svg+xml'){
- replaceSVG();
+ OC.Util.replaceSVG();
SVGSupport.checkMimeType.correct=false;
}
}
@@ -793,35 +793,10 @@ SVGSupport.checkMimeType=function(){
};
SVGSupport.checkMimeType.correct=true;
-//replace all svg images with png for browser compatibility
-function replaceSVG(){
- $('img.svg').each(function(index,element){
- element=$(element);
- var src=element.attr('src');
- element.attr('src',src.substr(0,src.length-3)+'png');
- });
- $('.svg').each(function(index,element){
- element=$(element);
- var background=element.css('background-image');
- if(background){
- var i=background.lastIndexOf('.svg');
- if(i>=0){
- background=background.substr(0,i)+'.png'+background.substr(i+4);
- element.css('background-image',background);
- }
- }
- element.find('*').each(function(index,element) {
- element=$(element);
- var background=element.css('background-image');
- if(background){
- var i=background.lastIndexOf('.svg');
- if(i>=0){
- background=background.substr(0,i)+'.png'+background.substr(i+4);
- element.css('background-image',background);
- }
- }
- });
- });
+// replace all svg images with png for browser compatibility
+// @deprecated use OC.Util.replaceSVG instead
+function replaceSVG($el){
+ return OC.Util.replaceSVG($el);
}
/**
@@ -899,8 +874,8 @@ function initCore() {
initSessionHeartBeat();
}
- if(!SVGSupport()){ //replace all svg images with png images for browser that dont support svg
- replaceSVG();
+ if(!OC.Util.hasSVGSupport()){ //replace all svg images with png images for browser that dont support svg
+ OC.Util.replaceSVG();
}else{
SVGSupport.checkMimeType();
}
@@ -1134,6 +1109,72 @@ function relative_modified_date(timestamp) {
else { return t('core','years ago'); }
}
+OC.Util = {
+ /**
+ * Returns whether the browser supports SVG
+ *
+ * @return true if the browser supports SVG, false otherwise
+ */
+ // TODO: replace with original function
+ hasSVGSupport: SVGSupport,
+ /**
+ * If SVG is not supported, replaces the given icon's extension
+ * from ".svg" to ".png".
+ * If SVG is supported, return the image path as is.
+ *
+ * @param file image path with svg extension
+ * @return fixed image path with png extension if SVG is not
+ * supported
+ */
+ replaceSVGIcon: function(file) {
+ if (!OC.Util.hasSVGSupport()) {
+ var i = file.lastIndexOf('.svg');
+ if (i >= 0) {
+ file = file.substr(0, i) + '.png' + file.substr(i+4);
+ }
+ }
+ return file;
+ },
+ /**
+ * Replace SVG images in all elements that have the "svg" class set
+ * with PNG images.
+ *
+ * @param $el root element from which to search, defaults to $('body')
+ */
+ replaceSVG: function($el) {
+ if (!$el) {
+ $el = $('body');
+ }
+ $el.find('img.svg').each(function(index,element){
+ element=$(element);
+ var src=element.attr('src');
+ element.attr('src',src.substr(0, src.length-3) + 'png');
+ });
+ $el.find('.svg').each(function(index,element){
+ element = $(element);
+ var background = element.css('background-image');
+ if (background){
+ var i = background.lastIndexOf('.svg');
+ if (i >= 0){
+ background = background.substr(0,i) + '.png' + background.substr(i + 4);
+ element.css('background-image', background);
+ }
+ }
+ element.find('*').each(function(index, element) {
+ element = $(element);
+ var background = element.css('background-image');
+ if (background) {
+ var i = background.lastIndexOf('.svg');
+ if(i >= 0){
+ background = background.substr(0,i) + '.png' + background.substr(i + 4);
+ element.css('background-image', background);
+ }
+ }
+ });
+ });
+ }
+};
+
/**
* get a variable by name
* @param string name